# Verifiably Checker

This library offers an easy way to verify the results sent by a vfunction. For more details about the process visit the [Attestation Documentation](https://developer.verifiably.com/docs/vfunctions/attestation).

## Installation
To install this library run:

```
pip install verifiably_checker
```
